from setuptools import find_packages, setup
setup(
    name='test-python-lib',
    packages=find_packages(),
    version='0.1.2',
    description='My first Python library',
    author='Me',
    license='MIT',
)
